==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/lib/l10n/et_EE.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ei saa kirjutada \"config\" kataloogi!",
    "See %s" : "Vaata %s",
    "Sample configuration detected" : "Tuvastati näidisseaded",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Tuvastati, et kopeeriti näidisseaded. See võib lõhkuda sinu saidi ja see pole toetatud. Palun loe enne faili config.php muutmist dokumentatsiooni",
    "%1$s and %2$s" : "%1$s ja %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ja %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ja %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ja %5$s",
    "PHP %s or higher is required." : "PHP %s või uuem on nõutav.",
    "PHP with a version lower than %s is required." : "Nõutud on PHP madalama versiooniga kui %s.",
    "The command line tool %s could not be found" : "Käsurea töövahendit %s ei leitud",
    "The library %s is not available." : "Teek %s pole saadaval.",
    "Server version %s or higher is required." : "Serveri versioon %s või kõrgem on nõutav.",
    "Server version %s or lower is required." : "Serveri versioon %s või madalam on nõutav.",
    "Authentication" : "Autentimine",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Invalid image" : "Vigane pilt",
    "Avatar image is not square" : "Avatari pilt pole ruut",
    "Files" : "Failid",
    "View profile" : "Vaata profiili",
    "today" : "täna",
    "tomorrow" : "homme",
    "yesterday" : "eile",
    "_%n day ago_::_%n days ago_" : ["%n päev tagasi","%n päeva tagasi"],
    "next month" : "järgmine kuu",
    "last month" : "viimasel kuul",
    "next year" : "järgmine aasta",
    "last year" : "viimasel aastal",
    "_%n year ago_::_%n years ago_" : ["%n aasta tagasi","%n aastat tagasi"],
    "_%n hour ago_::_%n hours ago_" : ["%n tund tagasi","%n tundi tagasi"],
    "in a few seconds" : "mõne sekundi jooksul",
    "seconds ago" : "sekundit tagasi",
    "Empty file" : "Tühi fail",
    "Dot files are not allowed" : "Punktiga failid pole lubatud",
    "File already exists" : "Fail on juba olemas",
    "Invalid path" : "Vigane kataloogirada",
    "Failed to create file from template" : "Ei saa luua mallist faili",
    "Templates" : "Mallid",
    "Filename contains at least one invalid character" : "Faili nimes on vähemalt üks keelatud märk",
    "Empty filename is not allowed" : "Tühi failinimi pole lubatud",
    "__language_name__" : "Eesti",
    "This is an automatically sent email, please do not reply." : "See on automaatselt saadetud e-kiri, palun ära vasta.",
    "Apps" : "Rakendused",
    "Personal settings" : "Isiklikud seaded",
    "Administration settings" : "Administreerimise seaded",
    "Settings" : "Seaded",
    "Log out" : "Logi välja",
    "Email" : "Epost",
    "Phone" : "Telefon",
    "Twitter" : "Twitter",
    "Website" : "Veebileht",
    "Address" : "Aadress",
    "Profile picture" : "Profiili pilt",
    "About" : "Info",
    "Display name" : "Kuvatav nimi",
    "Organisation" : "Organisatsioon",
    "Role" : "Roll",
    "Additional settings" : "Lisaseaded",
    "You need to enter details of an existing account." : "Sa pead sisestama olemasoleva konto andmed.",
    "Oracle connection could not be established" : "Ei suuda luua ühendust Oracle baasiga",
    "For the best results, please consider using a GNU/Linux server instead." : "Parema tulemuse saavitamiseks palun kaalu serveris GNU/Linux kasutamist.",
    "Set an admin password." : "Määra admini parool.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Jagamise tagarakend %s peab kasutusele võtma OCP\\Share_Backend liidese",
    "Sharing backend %s not found" : "Jagamise tagarakendit %s ei leitud",
    "Sharing backend for %s not found" : "Jagamise tagarakendit %s jaoks ei leitud",
    "%1$s via %2$s" : "%1$s %2$s kaudu",
    "Unknown share type" : "Tundmatu jagamise tüüp",
    "You are not allowed to share %s" : "Sul pole lubatud %s jagada",
    "Cannot increase permissions of %s" : "Ei saa %s õigusi suurendada",
    "Expiration date is in the past" : "Aegumise kuupäev on minevikus",
    "Sharing %s failed, because this item is already shared with the account %s" : "%s jagamine ebaõnnestus, kuna seda üksust on juba jagatud kontoga %s",
    "The requested share does not exist anymore" : "Soovitud jagamist enam ei eksisteeri",
    "Could not find category \"%s\"" : "Ei leia kategooriat \"%s\"",
    "Sunday" : "Pühapäev",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sun." : "P",
    "Mon." : "E",
    "Tue." : "T",
    "Wed." : "K",
    "Thu." : "N",
    "Fri." : "R",
    "Sat." : "L",
    "Su" : "P",
    "Mo" : "E",
    "Tu" : "T",
    "We" : "K",
    "Th" : "N",
    "Fr" : "R",
    "Sa" : "L",
    "January" : "Jaanuar",
    "February" : "Veebruar",
    "March" : "Märts",
    "April" : "Aprill",
    "May" : "Mai",
    "June" : "Juuni",
    "July" : "Juuli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktoober",
    "November" : "November",
    "December" : "Detsember",
    "Jan." : "Jaan.",
    "Feb." : "Veebr.",
    "Mar." : "Märts.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Juuni.",
    "Jul." : "Juuli.",
    "Aug." : "Aug.",
    "Sep." : "Sept.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dets.",
    "A valid password must be provided" : "Sisesta nõuetele vastav parool",
    "a safe home for all your data" : "turvaline koht sinu andmetele",
    "Application is not enabled" : "Rakendus pole sisse lülitatud",
    "Authentication error" : "Autentimise viga",
    "Token expired. Please reload page." : "Kontrollkood aegus. Paelun lae leht uuesti.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ühtegi andmebaasi (sqlite, mysql või postgresql) draiverit pole paigaldatud.",
    "PHP module %s not installed." : "PHP moodulit %s pole paigaldatud.",
    "Please ask your server administrator to install the module." : "Palu oma serveri haldajal moodul paigadalda.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP seade \"%s\" ei ole \"%s\".",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moodulid on paigaldatud, kuid neid näitatakse endiselt kui puuduolevad?",
    "Please ask your server administrator to restart the web server." : "Palu oma serveri haldajal veebiserver taaskäivitada.",
    "Your data directory is invalid." : "Sinu andmekataloog on vigane",
    "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust \"%s\".",
    "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
    "Text" : "Tekst",
    "Summary" : "Kokkuvõte",
    "Translate" : "Tõlgi",
    "File name is a reserved word" : "Failinimi sisaldab keelatud sõna",
    "File name contains at least one invalid character" : "Faili nimesonvähemalt üks keelatud märk",
    "File name is too long" : "Faili nimi on liiga pikk",
    "Users" : "Kasutajad",
    "Open »%s«" : "Ava »%s«",
    "Click the button below to open it." : "Vajuta allolevat nuppu, et see avada.",
    "File is currently busy, please try again later" : "Fail on hetkel kasutuses, proovi hiljem uuesti"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/lib/l10n/et_EE.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ei saa kirjutada \"config\" kataloogi!",
    "See %s" : "Vaata %s",
    "Sample configuration detected" : "Tuvastati näidisseaded",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Tuvastati, et kopeeriti näidisseaded. See võib lõhkuda sinu saidi ja see pole toetatud. Palun loe enne faili config.php muutmist dokumentatsiooni",
    "%s email verification" : "E-postiaadressi kinnitamine: %s",
    "Email verification" : "E-postiaadressi kinnitamine",
    "Click the following button to confirm your email." : "Oma e-postiaadressi kinnitamiseks klõpsi järgmisel nupul.",
    "Click the following link to confirm your email." : "Oma e-postiaadressi kinnitamiseks klõpsi järgmisel lingil.",
    "Confirm your email" : "Kiinita oma e-posti aadress",
    "Other activities" : "Muud tegevused",
    "%1$s and %2$s" : "%1$s ja %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ja %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ja %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ja %5$s",
    "PHP %s or higher is required." : "PHP %s või uuem on nõutav.",
    "PHP with a version lower than %s is required." : "Nõutud on PHP madalama versiooniga kui %s.",
    "The command line tool %s could not be found" : "Käsurea töövahendit %s ei leitud",
    "The library %s is not available." : "Teek %s pole saadaval.",
    "The following platforms are supported: %s" : "Toetatud on järgmised platvormid: %s",
    "Server version %s or higher is required." : "Serveri versioon %s või kõrgem on nõutav.",
    "Server version %s or lower is required." : "Serveri versioon %s või madalam on nõutav.",
    "Wiping of device %s has finished" : "„%s“ seadme kustutamine on lõppenud",
    "Wiping of device »%s« has finished" : "„%s“ seadme kustutamine on lõppenud",
    "Remote wipe started" : "Kaugkustutamine on alanud",
    "A remote wipe was started on device %s" : "„%s“ seadme kaugkustutamine on alanud",
    "Remote wipe finished" : "Kaugkustutamine on lõppenud",
    "The remote wipe on %s has finished" : "„%s“ seadme kaugkustutamine on lõppenud",
    "Authentication" : "Autentimine",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Invalid image" : "Vigane pilt",
    "Avatar image is not square" : "Avatari pilt pole ruut",
    "Files" : "Failid",
    "View profile" : "Vaata profiili",
    "same time" : "samas ajas",
    "today" : "täna",
    "tomorrow" : "homme",
    "yesterday" : "eile",
    "_%n day ago_::_%n days ago_" : ["%n päev tagasi","%n päeva tagasi"],
    "next month" : "järgmine kuu",
    "last month" : "viimasel kuul",
    "_in %n month_::_in %n months_" : ["%n kuu pärast","%n kuu pärast"],
    "_%n month ago_::_%n months ago_" : ["%n kuu eest","%n kuu eest"],
    "next year" : "järgmine aasta",
    "last year" : "viimasel aastal",
    "_in %n year_::_in %n years_" : ["%n aasta pärast","%n aasta pärast"],
    "_%n year ago_::_%n years ago_" : ["%n aasta tagasi","%n aastat tagasi"],
    "_in %n hour_::_in %n hours_" : ["%n tunni pärast","%n tunni pärast"],
    "_%n hour ago_::_%n hours ago_" : ["%n tund tagasi","%n tundi tagasi"],
    "_in %n minute_::_in %n minutes_" : ["%n minuti pärast","%n minuti pärast"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minut tagasi","%n minutit tagasi"],
    "in a few seconds" : "mõne sekundi jooksul",
    "seconds ago" : "sekundit tagasi",
    "Empty file" : "Tühi fail",
    "File is too large to convert" : "Fail on teisendamiseks liiga suur",
    "Dot files are not allowed" : "Punktiga failid pole lubatud",
    "Filenames must not end with \"%1$s\"." : "Failinimede lõpus ei tohi olla „%1$s“.",
    "File already exists" : "Fail on juba olemas",
    "Invalid path" : "Vigane kataloogirada",
    "Failed to create file from template" : "Ei saa luua mallist faili",
    "Templates" : "Mallid",
    "Filename contains at least one invalid character" : "Faili nimes on vähemalt üks keelatud märk",
    "Empty filename is not allowed" : "Tühi failinimi pole lubatud",
    "__language_name__" : "Eesti",
    "This is an automatically sent email, please do not reply." : "See on automaatselt saadetud e-kiri, palun ära vasta.",
    "Help & privacy" : "Abiteave ja privaatsus",
    "Appearance and accessibility" : "Välimus ja hõlpsus",
    "Apps" : "Rakendused",
    "Personal settings" : "Isiklikud seaded",
    "Administration settings" : "Administreerimise seaded",
    "Settings" : "Seaded",
    "Log out" : "Logi välja",
    "Accounts" : "Kasutajakontod",
    "Email" : "Epost",
    "Fediverse" : "Födiversum",
    "View %s on the fediverse" : "Vaata Födiversumis: %s",
    "Phone" : "Telefon",
    "Call %s" : "Helista: %s",
    "Twitter" : "X / Twitter",
    "View %s on Twitter" : "Vaata X-is / Twitteris: %s",
    "Website" : "Veebileht",
    "Visit %s" : "Külasta veebilehte: %s",
    "Address" : "Aadress",
    "Profile picture" : "Profiilipilt",
    "About" : "Info",
    "Display name" : "Kuvatav nimi",
    "Headline" : "Alapealkiri",
    "Organisation" : "Organisatsioon",
    "Role" : "Roll",
    "Pronouns" : "Asesõnad pöördumisel",
    "Unknown account" : "Tundmatu kasutajakonto",
    "Additional settings" : "Lisaseaded",
    "You need to enter details of an existing account." : "Sa pead sisestama olemasoleva konto andmed.",
    "Oracle connection could not be established" : "Ei suuda luua ühendust Oracle baasiga",
    "For the best results, please consider using a GNU/Linux server instead." : "Parema tulemuse saavitamiseks palun kaalu serveris GNU/Linux kasutamist.",
    "Set an admin Login." : "Lisa peakasutaja kasutajanimi.",
    "Set an admin password." : "Lisa peakasutaja salasõna.",
    "Cannot create or write into the data directory %s" : "Ei õnnestu luua „%s“ andmekausta või sealt lugeda",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Jagamise tagarakend %s peab kasutusele võtma OCP\\Share_Backend liidese",
    "Sharing backend %s not found" : "Jagamise tagarakendit %s ei leitud",
    "Sharing backend for %s not found" : "Jagamise tagarakendit %s jaoks ei leitud",
    "%1$s shared %2$s with you" : "%1$s jagas sinuga: %2$s",
    "Open %s" : "Ava %s ",
    "%1$s via %2$s" : "%1$s %2$s kaudu",
    "%1$s shared %2$s with you and wants to add:" : "%1$s jagas sinuga %2$s ning soovib lisada:",
    "%1$s shared %2$s with you and wants to add" : "%1$s jagas sinuga %2$s ning soovib lisada",
    "Unknown share type" : "Tundmatu jagamise tüüp",
    "You are not allowed to share %s" : "Sul pole lubatud %s jagada",
    "Cannot increase permissions of %s" : "Ei saa %s õigusi suurendada",
    "Expiration date is in the past" : "Aegumise kuupäev on minevikus",
    "Sharing %s failed, because this item is already shared with the account %s" : "%s jagamine ebaõnnestus, kuna seda üksust on juba jagatud kontoga %s",
    "The requested share does not exist anymore" : "Soovitud jagamist enam ei eksisteeri",
    "Could not find category \"%s\"" : "Ei leia kategooriat \"%s\"",
    "Sunday" : "Pühapäev",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sun." : "P",
    "Mon." : "E",
    "Tue." : "T",
    "Wed." : "K",
    "Thu." : "N",
    "Fri." : "R",
    "Sat." : "L",
    "Su" : "P",
    "Mo" : "E",
    "Tu" : "T",
    "We" : "K",
    "Th" : "N",
    "Fr" : "R",
    "Sa" : "L",
    "January" : "Jaanuar",
    "February" : "Veebruar",
    "March" : "Märts",
    "April" : "Aprill",
    "May" : "Mai",
    "June" : "Juuni",
    "July" : "Juuli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktoober",
    "November" : "November",
    "December" : "Detsember",
    "Jan." : "Jaan.",
    "Feb." : "Veebr.",
    "Mar." : "Märts.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Juuni.",
    "Jul." : "Juuli.",
    "Aug." : "Aug.",
    "Sep." : "Sept.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dets.",
    "A valid password must be provided" : "Sisesta nõuetele vastav parool",
    "a safe home for all your data" : "turvaline koht sinu andmetele",
    "Application is not enabled" : "Rakendus pole sisse lülitatud",
    "Authentication error" : "Autentimise viga",
    "Token expired. Please reload page." : "Kontrollkood aegus. Paelun laadi leht uuesti.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ühtegi andmebaasi (sqlite, mysql või postgresql) draiverit pole paigaldatud.",
    "PHP module %s not installed." : "PHP moodulit %s pole paigaldatud.",
    "Please ask your server administrator to install the module." : "Palu oma serveri haldajal moodul paigadalda.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP seade \"%s\" ei ole \"%s\".",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moodulid on paigaldatud, kuid neid näitatakse endiselt kui puuduolevad?",
    "Please ask your server administrator to restart the web server." : "Palu oma serveri haldajal veebiserver taaskäivitada.",
    "Your data directory is invalid." : "Sinu andmekataloog on vigane",
    "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust \"%s\".",
    "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
    "Text" : "Tekst",
    "Summary" : "Kokkuvõte",
    "Translate" : "Tõlgi",
    "The translated text" : "Tõlgitud tekst",
    "File name is a reserved word" : "Failinimi sisaldab keelatud sõna",
    "File name contains at least one invalid character" : "Failinimes on vähemalt üks keelatud tähemärk",
    "File name is too long" : "Failinimi on liiga pikk",
    "Users" : "Kasutajad",
    "Open »%s«" : "Ava »%s«",
    "%1$s shared »%2$s« with you." : "%1$s jagas sinuga „%2$s“ faili.",
    "Click the button below to open it." : "Vajuta allolevat nuppu, et see avada.",
    "File is currently busy, please try again later" : "Fail on hetkel kasutuses, proovi hiljem uuesti"
},
"nplurals=2; plural=(n != 1);");
